import { Addresses, ConfigPreset, NodePreset } from '../model';
import { Preset } from './ConfigService';
import { flags } from '@oclif/command';
export declare class BootstrapUtils {
    static readonly defaultTargetFolder = "target";
    static readonly targetNodesFolder = "nodes";
    static readonly targetGatewaysFolder = "gateways";
    static readonly targetDatabasesFolder = "databases";
    static readonly targetNemesisFolder = "nemesis";
    static readonly CURRENT_USER = "current";
    private static readonly pulledImages;
    private static presetInfoLogged;
    private static stopProcess;
    static helpFlag: import("@oclif/parser/lib/flags").IBooleanFlag<void>;
    static targetFlag: flags.IOptionFlag<string>;
    private static onProcessListener;
    static deleteFolder(folder: string, excludeFiles?: string[]): void;
    private static deleteFolderRecursive;
    static deleteFile(file: string): void;
    static showBanner(): void;
    static validateIsDefined(value: any, message: string): void;
    static pullImage(image: string): Promise<void>;
    static runImageUsingExec({ catapultAppFolder, image, userId, workdir, cmds, binds, }: {
        catapultAppFolder: string;
        image: string;
        userId?: string | undefined;
        workdir?: string | undefined;
        cmds: string[];
        binds: string[];
    }): Promise<{
        stdout: string;
        stderr: string;
    }>;
    static loadPresetData(root: string, preset: Preset, assembly: string | undefined, customPresetFile: string | undefined, customPresetObject: any | undefined): ConfigPreset;
    static dynamicDefaultNodeConfiguration(nodes?: NodePreset[]): NodePreset[];
    private static resolveRoles;
    static expandRepeat(presetData: ConfigPreset): ConfigPreset;
    static applyValueTemplate(context: any, value: any): any;
    static expandServicesRepeat(context: any, services: any[]): any[];
    static loadExistingPresetData(target: string): ConfigPreset;
    static getGeneratedPresetLocation(target: string): string;
    static loadExistingAddresses(target: string): Addresses;
    static getGeneratedAddressLocation(target: string): string;
    static sleep(ms: number): Promise<any>;
    static createVotingKey(votingPublicKey: string): string;
    static poll(promiseFunction: () => Promise<boolean>, totalPollingTime: number, pollIntervalMs: number): Promise<boolean>;
    static generateConfiguration(templateContext: any, copyFrom: string, copyTo: string): Promise<void>;
    static mkdir(path: string): Promise<void>;
    static writeYaml(path: string, object: any): Promise<void>;
    static toYaml(object: any): string;
    static fromYaml(yamlString: string): any;
    static loadYaml(fileLocation: string): any;
    static loadFileAsText(fileLocation: string): string;
    static writeTextFile(path: string, text: string): Promise<void>;
    static readTextFile(path: string): Promise<string>;
    private static dockerUserId;
    static resolveDockerUserFromParam(paramUser: string | undefined): Promise<string | undefined>;
    static createImageUsingExec(targetFolder: string, dockerFile: string, tag: string): Promise<string>;
    static exec(runCommand: string): Promise<{
        stdout: string;
        stderr: string;
    }>;
    static spawn(command: string, args: string[], useLogger: boolean): Promise<string>;
    static getDockerUserGroup(): Promise<string>;
    static validateFolder(workingDirFullPath: string): void;
    static getTargetFolder(target: string, absolute: boolean, ...paths: string[]): string;
    static getTargetNodesFolder(target: string, absolute: boolean, ...paths: string[]): string;
    static getTargetGatewayFolder(target: string, absolute: boolean, ...paths: string[]): string;
    static getTargetNemesisFolder(target: string, absolute: boolean, ...paths: string[]): string;
    static getTargetDatabasesFolder(target: string, absolute: boolean, ...paths: string[]): string;
    private static initialize;
    private static add;
    private static minus;
    static toAmount(renderedText: string | number): string;
    static toHex(renderedText: string): string;
    static toSimpleHex(renderedText: string): string;
    static toJson(object: any): string;
}
