import { Account, NetworkType } from 'symbol-sdk';
import { Addresses, ConfigAccount, ConfigPreset, NodeAccount, NodePreset } from '../model';
/**
 * Defined presets.
 */
export declare enum Preset {
    bootstrap = "bootstrap",
    testnet = "testnet"
}
export interface ConfigParams {
    report: boolean;
    reset: boolean;
    preset: Preset;
    target: string;
    user: string;
    assembly?: string;
    customPreset?: string;
    customPresetObject?: any;
}
export interface ConfigResult {
    addresses: Addresses;
    presetData: ConfigPreset;
}
export declare class ConfigService {
    private readonly root;
    private readonly params;
    static defaultParams: ConfigParams;
    constructor(root: string, params: ConfigParams);
    toConfig(account: Account): ConfigAccount;
    static getNetworkIdentifier(networkType: NetworkType): string;
    static getNetworkName(networkType: NetworkType): string;
    generateAddresses(networkType: NetworkType, size: number): ConfigAccount[];
    generateAccount(networkType: NetworkType, privateKey: string | undefined): Account;
    generateNodeAccount(index: number, nodePreset: NodePreset, networkType: NetworkType): Promise<NodeAccount>;
    generateNodeAccounts(networkType: NetworkType, nodes: NodePreset[]): Promise<NodeAccount[]>;
    private static getArray;
    run(): Promise<ConfigResult>;
    private generateNemesis;
    private generateRandomConfiguration;
    private generateNodes;
    private generateNodeConfiguration;
    private generateP2PFile;
    private generateNemesisConfig;
    private createVrfTransaction;
    private createVotingKeyTransaction;
    private storeTransaction;
    private generateGateways;
}
